@@ -321,7 +321,7 @@ impl fmt::Display for Field {
 }
 
 #[cfg(test)]
-mod test {
+mod tests {
 
     use pretty_assertions::assert_eq;
 
